# [0.2.9](https://github.com/seriaati/akasha-py/compare/v0.2.8..v0.2.9) - 2024-12-30

## Bug Fixes

- Fix field alias name in WeaponLeaderboardFilter.name - ([9d65138](https://github.com/seriaati/akasha-py/commit/9d65138eaabc85e8894b768c1d54773025eae9b3))
- Fix ValidationError in WeaponLeaderboard.filters when passed in value is null - ([5053d97](https://github.com/seriaati/akasha-py/commit/5053d975fb390dffa65f9bea5b0aa8c51763f1b7))

## Features

-  [**breaking**]Add uids and variant params to get_leaderboards method - ([a536bee](https://github.com/seriaati/akasha-py/commit/a536bee41d2b0ced3a4d1a1d1485e518cea75d6a))
- Add filters field to WeaponLeaderboard - ([2f887ed](https://github.com/seriaati/akasha-py/commit/2f887ed99845b3da0f52390fe224a068f28bbae9))

## Miscellaneous Chores

- **(deps)** Update astral-sh/setup-uv action to v4 ([#43](https://github.com/seriaati/akasha-py/issues/43)) - ([aea9ff2](https://github.com/seriaati/akasha-py/commit/aea9ff2a1c36e591668ccbd8fe071a2ee4b78b06))
- **(deps)** lock file maintenance ([#44](https://github.com/seriaati/akasha-py/issues/44)) - ([36ac831](https://github.com/seriaati/akasha-py/commit/36ac8317b1289a83c1c0b09bcfdf358d3f6604ff))
- **(deps)** lock file maintenance ([#45](https://github.com/seriaati/akasha-py/issues/45)) - ([2a3768b](https://github.com/seriaati/akasha-py/commit/2a3768b76a88c84f96313b28a44a15711ec0de4c))
- **(deps)** update astral-sh/ruff-action action to v2 ([#46](https://github.com/seriaati/akasha-py/issues/46)) - ([9d4d068](https://github.com/seriaati/akasha-py/commit/9d4d068906cd7d11936108207a39be25ef3b8c96))
- **(deps)** lock file maintenance ([#47](https://github.com/seriaati/akasha-py/issues/47)) - ([f0896c5](https://github.com/seriaati/akasha-py/commit/f0896c57127349697e1579bca8afd2dd2db9f621))
- **(deps)** lock file maintenance ([#48](https://github.com/seriaati/akasha-py/issues/48)) - ([65b2062](https://github.com/seriaati/akasha-py/commit/65b2062d0a568c7b8f16b421b066ea4dbca13784))
- **(deps)** lock file maintenance ([#50](https://github.com/seriaati/akasha-py/issues/50)) - ([7b9452e](https://github.com/seriaati/akasha-py/commit/7b9452e77400b35e2888c25acbbe672eef6d8e2a))
- **(deps)** update astral-sh/setup-uv action to v5 ([#49](https://github.com/seriaati/akasha-py/issues/49)) - ([a07b6c8](https://github.com/seriaati/akasha-py/commit/a07b6c8001199f45ca222bd4d05575134c03a8d9))
- **(deps)** update astral-sh/ruff-action action to v3 ([#51](https://github.com/seriaati/akasha-py/issues/51)) - ([7b09759](https://github.com/seriaati/akasha-py/commit/7b097594ad41338d47f53567d84f3b34f256ce7b))

